\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ivtuniyarconf}[2021/03/01]
\LoadClass[a5paper]{article}
\RequirePackage[backend=biber,style=gost-numeric,language=auto,autolang=other,sorting=none,movenames=false]{biblatex}
\RequirePackage[T2A]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage[english,russian]{babel}
\RequirePackage{indentfirst}
\RequirePackage[colorlinks=true,urlcolor=blue,linkcolor=blue,citecolor=blue]{hyperref}
\RequirePackage[margin=2cm,bottom=2.5cm]{geometry}
\RequirePackage{graphicx}
\RequirePackage{enumitem}
\RequirePackage{url}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsthm}
\RequirePackage{xstring}

\newtheorem{theorem}{Теорема}
\newtheorem{lemma}{Лемма}
\newtheorem{corollary}{Следствие}

\setlist{nosep}

\renewcommand{\abstractname}{\vspace{-\baselineskip}} %%%%

\clubpenalty=10000 
\widowpenalty=10000

\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
  \oldbibliography{#1}%
  \setlength{\itemsep}{-3pt}%
}
\renewcommand*{\newblockpunct}{\addperiod\space\bibsentence}

\let\footnoterule\relax

\newcommand{\keywords}[1]{\textbf{Ключевые слова:} #1}

\gdef\@author{}
\gdef\@advisor{}
\gdef\@authorrev{}
\gdef\@email{}
\gdef\@advisortitle{}
\newcommand\udc[1]{\gdef\@udc{#1}}
\renewcommand{\author}[1]{
  \StrBefore{#1}{ }[\lastname]
  \StrBehind{#1}{ }[\nametail]
  \StrBefore{\nametail}{ }[\firstname]
  \StrBehind{\nametail}{ }[\middlename]
  \StrLeft{\firstname}{1}[\firstinitial]
  \StrLeft{\middlename}{1}[\middleinitial]
  \def\initials{\firstinitial.\,\middleinitial.}
  \ifx\@author\empty
    \xdef\@author{\initials~\lastname}
    \xdef\@authorrev{\lastname~\initials}
  \else
    \xdef\@author{\@author, \initials~\lastname}
    \xdef\@authorrev{\@authorrev, \lastname~\initials}
  \fi
}
\newcommand{\authorstatus}[2]{}
\newcommand{\advisor}[2]{
  \StrBefore{#2}{ }[\lastname]
  \StrBehind{#2}{ }[\nametail]
  \StrBefore{\nametail}{ }[\firstname]
  \StrBehind{\nametail}{ }[\middlename]
  \StrLeft{\firstname}{1}[\firstinitial]
  \StrLeft{\middlename}{1}[\middleinitial]
  \def\initials{\firstinitial.\,\middleinitial.}
  \ifx\@advisor\empty
    \xdef\@advisor{#1~\initials~\lastname}
    \xdef\@advisortitle{Научный руководитель: }
  \else
    \xdef\@advisor{\@advisor, #1~\initials~\lastname}
    \xdef\@advisortitle{Научные руководители: }
  \fi  
}
\newcommand{\affiliation}[1]{\gdef\@affiliation{#1}}
\newcommand{\email}[1]{
  \ifx\@email\empty
    \xdef\@email{#1}
  \else
    \xdef\@email{\@email, #1}
  \fi  
}
\newcommand{\advisoremail}[1]{
}

\renewcommand\section{\@startsection {section}{1}{\z@}%
  {-2ex \@plus -1ex \@minus -.2ex}%
  {0.5ex \@plus.2ex}%
  {\normalfont\bfseries}}

\renewenvironment{abstract}{%
  \small\quotation\setlength\parindent{0pt}\noindent\textbf{\abstractname.}%
  }
{\vspace*{-3mm}\endquotation\rule{\textwidth}{0.2mm}\vspace*{2mm}}

\def\@maketitle{%
  \setlength{\parindent}{0mm}
  \newpage
  \null
  \vspace*{-7.5mm}
  {\footnotesize

    \begin{center}
      \textsf{Всероссийская молодёжная научно-практическая конференция\\
        «Путь в науку: прикладная математика, информатика\\ и информационные технологии».
        Ярославль, ЯрГУ, 19--23 апреля 2021 г.\\
        Секция \ifdef{\confsection}{«\confsection»}{}}\\[-1mm]
      \rule{\textwidth}{0.2mm}
    \end{center}
    \vspace*{-3mm}  
    УДК \@udc    
  }
  \vspace*{-2mm}
  \begin{center}%
    \let\thefootnote\relax%
    \footnote{\textcopyright\ \@authorrev, 2021}%
    \textbf{\@title}\par
    \vskip 0.5em%
    \@author\par
    {\small E-mail: \@email\par}
    \vskip 0.5em%
    {\small\@advisortitle\@advisor\par}
    {\small\@affiliation\par}
  \end{center}
  \par
}
